@@ -1,16 +1,6 @@
-pref("ctxextensions.enable.debug_mode", false);
-
 pref("ctxextensions.enable.expert_prefs", false);
 pref("ctxextensions.enable.nsIXULTemplateBuilder", false);
 pref("ctxextensions.enable.cite_as_href", false);
-pref("ctxextensions.enable.popupToTop_TL", false);
-pref("ctxextensions.enable.popupToTop_TR", false);
-pref("ctxextensions.enable.popupToTop_BL", false);
-pref("ctxextensions.enable.popupToTop_BR", false);
-pref("ctxextensions.enable.popupToEnd_TL", false);
-pref("ctxextensions.enable.popupToEnd_TR", false);
-pref("ctxextensions.enable.popupToEnd_BL", false);
-pref("ctxextensions.enable.popupToEnd_BR", false);
 pref("ctxextensions.enable.getLinks_collectOnClick", false);
 pref("ctxextensions.enable.navigations_advanced", false);
 pref("ctxextensions.enable.navigations_collectLinks", false);
@@ -19,11 +9,9 @@ pref("ctxextensions.enable.navigations_submenu", true);
 pref("ctxextensions.styleManager.userContentCSS_reload_alert", true);
 
 pref("ctxextensions.scan_navigations_in_background.enable",   false);
-pref("ctxextensions.scan_navigations_in_background.interval", 1000);
 pref("ctxextensions.scan_outline_in_background.enable",       false);
-pref("ctxextensions.scan_outline_in_background.interval",     1000);
 
-pref("ctxextensions.JSPanel.page.number", 1);
+pref("ctxextensions.JSPanel.page.number", 5);
 pref("ctxextensions.JSPanel.page.last",   0);
 
 pref("ctxextensions.override.datasource_path", "");
@@ -45,7 +33,6 @@ pref("ctxextensions.show_item.context.execApps", true);
 pref("ctxextensions.show_item.context.extensions", true);
 pref("ctxextensions.show_item.context.getLinks", true);
 pref("ctxextensions.show_item.context.go", false);
-pref("ctxextensions.show_item.context.help", false);
 pref("ctxextensions.show_item.context.JSPanel", true);
 pref("ctxextensions.show_item.context.navigations", false);
 pref("ctxextensions.show_item.context.nextHeading", false);
@@ -68,20 +55,10 @@ pref("ctxextensions.show_item.context.showTitles", false);
 pref("ctxextensions.show_item.context.styleSheets", false);
 pref("ctxextensions.show_item.context.up", true);
 
-pref("ctxextensions.show_item.context.sep_exec", true);
-pref("ctxextensions.show_item.context.sep_extensions", true);
-pref("ctxextensions.show_item.context.sep_extensionsAbout", true);
-pref("ctxextensions.show_item.context.sep_extensionsMisc", true);
-pref("ctxextensions.show_item.context.sep_extensionsOpen", true);
-pref("ctxextensions.show_item.context.sep_navigations", true);
-pref("ctxextensions.show_item.context.sep_send", true);
-pref("ctxextensions.show_item.context.sep_show", true);
-
 // show in submenu
 pref("ctxextensions.submenu.context.customScripts", false);
 pref("ctxextensions.submenu.context.execApps", false);
 pref("ctxextensions.submenu.context.getLinks", true);
-pref("ctxextensions.submenu.context.help", true);
 pref("ctxextensions.submenu.context.JSPanel", true);
 pref("ctxextensions.submenu.context.navigations", false);
 pref("ctxextensions.submenu.context.nextHeading", false);
@@ -125,19 +102,17 @@ pref("ctxextensions.submenu.menubar.styleSheets", true);
 pref("ctxextensions.submenu.menubar.up", true);
 
 
-pref("ctxextensions.new_window.force", false);
-pref("ctxextensions.new_window.usetab", true);
-
-pref("ctxextensions.new_window.help", true);
-pref("ctxextensions.new_window.navigations", false);
-pref("ctxextensions.new_window.openCiteForEdit", true);
-pref("ctxextensions.new_window.openCiteForQuote", true);
-pref("ctxextensions.new_window.openLongdesc", true);
-pref("ctxextensions.new_window.openSelectionAsURI", true);
-pref("ctxextensions.new_window.sendStr", true);
-pref("ctxextensions.new_window.sendURI", true);
-pref("ctxextensions.new_window.styleSheets", true);
-pref("ctxextensions.new_window.up", false);
+pref("ctxextensions.showResultIn.forceNewWindowOrTab", false);
+// 0 = current, 10 = New tab, 20 = new window
+pref("ctxextensions.showResultIn.navigations",        0);
+pref("ctxextensions.showResultIn.openCiteForEdit",    10);
+pref("ctxextensions.showResultIn.openCiteForQuote",   10);
+pref("ctxextensions.showResultIn.openLongdesc",       10);
+pref("ctxextensions.showResultIn.openSelectionAsURI", 10);
+pref("ctxextensions.showResultIn.sendStr",            10);
+pref("ctxextensions.showResultIn.sendURI",            10);
+pref("ctxextensions.showResultIn.styleSheets",        10);
+pref("ctxextensions.showResultIn.up",                 0);
 
 
 pref("ctxextensions.width.navigations", 24);
