@@ -1,7 +1,7 @@
 // static class "ExtCommonUtils" 
 var ExtCommonUtils = {
 
-	debug : false,
+	debug : true,
 
 	activated : false,
 
@@ -11,11 +11,6 @@ var ExtCommonUtils = {
 	// vpeB 
 	// properties
 	
-	get isNewTypeBrowser() 
-	{
-		return this.browserURI.match(/^chrome:\/\/browser\//) ? true : false ;
-	},
-	
 	get browserURI() 
 	{
 		if (!this._browserURI) {
@@ -36,21 +31,10 @@ var ExtCommonUtils = {
 	},
 	_browserURI : null,
   
-	get isMail() 
-	{
-		return document.documentElement.id == 'messengerWindow';
-	},
- 
-	get isNavigatorWindow() 
-	{
-		return (Components.lookupMethod(window, 'top').call(window).document.documentElement.getAttribute('windowtype') == 'navigator:browser');
-	},
- 
 	get contextMenu() 
 	{
 		if (!this.mContextMenu)
-			this.mContextMenu = document.getElementById('contentAreaContextMenu') ||
-								document.getElementById('messagePaneContext'); // for Mail
+			this.mContextMenu = document.getElementById('contentAreaContextMenu');
 		return this.mContextMenu;
 	},
 	mContextMenu : null,
@@ -61,7 +45,7 @@ var ExtCommonUtils = {
 			this._browser = document.getElementById('content');
 			if (this._browser &&
 				(
-					this._browser.localName != 'browser' ||
+					this._browser.localName != 'browser' &&
 					this._browser.localName != 'tabbrowser'
 				)
 				)
@@ -163,21 +147,6 @@ var ExtCommonUtils = {
 		return CSSFile;
 	},
  
-	// Ge the revision of Mozilla. This property will return a numeric value like "1.1", "0.9", etc.
-	get mozRevision() 
-	{
-		var httpProtocolHandler = Components.classes['@mozilla.org/network/protocol;1?name=http'].getService(Components.interfaces.nsIHttpProtocolHandler);
-		var rev = Number(
-					httpProtocolHandler.misc
-					.replace(/^[^\d]+/, '')
-					.replace(/([^\d]+$|rc\d)/i, '')
-					.replace(/\./, '/')
-					.replace(/\./g, '')
-					.replace(/\//, '.')
-				);
-		return rev;
-	},
- 
 	// bZ[W 
 	get msg()
 	{
@@ -313,7 +282,6 @@ var ExtCommonUtils = {
 		return this.mWINMAN;
 	},
 	mWINMAN : null,
-
  
 	get PREF() 
 	{
@@ -634,25 +602,13 @@ var ExtCommonUtils = {
 			var newURI;
 			aURI = aURI || '';
 			if (aURI && aURI.match(/^file:/)) {
-				var tempLocalFile;
-				try {
-					var fileHandler = this.IOService.getProtocolHandler('file').QueryInterface(Components.interfaces.nsIFileProtocolHandler);
-					tempLocalFile = fileHandler.getFileFromURLSpec(aURI);
-				}
-				catch(ex) { // [[interchangeability for Mozilla 1.1]]
-					try {
-						tempLocalFile = this.IOService.getFileFromURLSpec(aURI);
-					}
-					catch(ex) { // [[interchangeability for Mozilla 1.0.x]]
-						tempLocalFile = Components.classes['@mozilla.org/file/local;1'].createInstance(Components.interfaces.nsILocalFile);
-						this.IOService.initFileFromURLSpec(tempLocalFile, aURI);
-					}
-				}
+				var fileHandler = this.IOService.getProtocolHandler('file').QueryInterface(Components.interfaces.nsIFileProtocolHandler);
+				var tempLocalFile = fileHandler.getFileFromURLSpec(aURI);
+
 				newURI = this.IOService.newFileURI(tempLocalFile); // we can use this instance with the nsIFileURL interface.
 			}
 			else {
-				newURI = Components.classes['@mozilla.org/network/standard-url;1'].createInstance(Components.interfaces.nsIURI);
-				newURI.spec = aURI;
+				newURI = this.IOService.newURI(aURI, null, null);
 			}
 
 			return newURI;
@@ -673,39 +629,19 @@ var ExtCommonUtils = {
 	// URLt@CpXɕϊ 
 	getFileFromURLSpec : function(aURI)
 	{
-		var URI = Components.classes['@mozilla.org/network/standard-url;1'].createInstance(Components.interfaces.nsIURI);
-			URI.spec = aURI;
+		var URI = this.IOService.newURI(aURI, null, null);
 
 		if (!URI.schemeIs('file')) return '';
 
-		var tempLocalFile;
-		try {
-			var fileHandler = this.IOService.getProtocolHandler('file').QueryInterface(Components.interfaces.nsIFileProtocolHandler);
-			tempLocalFile = fileHandler.getFileFromURLSpec(aURI);
-		}
-		catch(e) { // [[interchangeability for Mozilla 1.1]]
-			try {
-				tempLocalFile = this.IOService.getFileFromURLSpec(aURI);
-			}
-			catch(ex) { // [[interchangeability for Mozilla 1.0.x]]
-				tempLocalFile = Components.classes['@mozilla.org/file/local;1'].createInstance(Components.interfaces.nsILocalFile);
-				this.IOService.initFileFromURLSpec(tempLocalFile, aURI);
-			}
-		}
-		return tempLocalFile;
+		var fileHandler = this.IOService.getProtocolHandler('file').QueryInterface(Components.interfaces.nsIFileProtocolHandler);
+		return fileHandler.getFileFromURLSpec(aURI);
 	},
  
 	// t@CpXURIɕϊ 
 	getURLFromFilePath : function(aPath)
 	{
 		var tempLocalFile = this.makeFileWithPath(aPath);
-
-		try {
-			return this.IOService.newFileURI(tempLocalFile);
-		}
-		catch(e) { // [[interchangeability for Mozilla 1.1]]
-			return this.makeURIFromSpec(this.IOService.getURLSpecFromFile(tempLocalFile));
-		}
+		return this.IOService.newFileURI(tempLocalFile);
 	},
  
 	// URIURI𓾂 
@@ -1209,36 +1145,66 @@ var ExtCommonUtils = {
 		return windows;
 	},
  
-	// vf̓eLXg𓾂 
-	getInnerTextOf : function(aNode)
+	getWindowFromDocument : function(aDocument) 
 	{
-		if (!aNode || !aNode.firstChild) return '';
-		var node = aNode.firstChild;
+		if (aDocument.defaultView)
+			return aDocument.defaultView;
 
-		var depth = 1,
-			ret   = [];
+		var docShell = this.getDocShellFromDocument(aDocument);
+		return !docShell ? null :
+				docShell
+					.QueryInterface(Components.interfaces.nsIInterfaceRequestor)
+					.getInterface(Components.interfaces.nsIDOMWindow);
+	},
+ 
+	getDocShellFromDocument : function(aDocument, aRootDocShell) 
+	{
+		const kDSTreeNode = Components.interfaces.nsIDocShellTreeNode;
+		const kDSTreeItem = Components.interfaces.nsIDocShellTreeItem;
+		const kWebNav     = Components.interfaces.nsIWebNavigation;
 
-		traceTree:
-		while (node && depth > 0) {
-			if (node.hasChildNodes()) {
-				node = node.firstChild;
-				depth++;
+		if (aDocument.defaultView)
+			return aDocument.defaultView.QueryInterface(Components.interfaces.nsIInterfaceRequestor)
+					.getInterface(kWebNav)
+					.QueryInterface(Components.interfaces.nsIDocShell);
+
+		if (!aRootDocShell)
+			aRootDocShell = gBrowser.docShell;
+
+		var aRootDocShell = aRootDocShell
+				.QueryInterface(kDSTreeNode)
+				.QueryInterface(kDSTreeItem)
+				.QueryInterface(kWebNav);
+		var docShell = aRootDocShell;
+		traceDocShellTree:
+		do {
+			if (docShell.document == aDocument) {
+				return docShell;
+				break;
+			}
+
+			if (docShell.childCount) {
+				docShell = docShell.getChildAt(0);
+				docShell = docShell
+					.QueryInterface(kDSTreeNode)
+					.QueryInterface(kWebNav);
 			}
 			else {
-				if (node.nodeType == Node.TEXT_NODE)
-					ret.push(node.nodeValue);
-				else if ('alt' in node && node.alt)
-					ret.push(node.alt);
-
-				while (!node.nextSibling) {
-					node = node.parentNode;
-					depth--;
-					if (!node) break traceTree;
+				parentDocShell = docShell.parent.QueryInterface(kDSTreeNode);
+				while (docShell.childOffset == parentDocShell.childCount-1)
+				{
+					docShell = parentDocShell;
+					if (docShell == aRootDocShell || !docShell.parent)
+						break traceDocShellTree;
+					parentDocShell = docShell.parent.QueryInterface(kDSTreeNode);
 				}
-				node = node.nextSibling;
+				docShell = parentDocShell.getChildAt(docShell.childOffset+1)
+					.QueryInterface(kDSTreeNode)
+					.QueryInterface(kWebNav);
 			}
-		}
-		return ret.join('');
+		} while (docShell != aRootDocShell);
+
+		return null;
 	},
  
 	// vf̃\[X𓾂 
@@ -1393,7 +1359,7 @@ var ExtCommonUtils = {
 
 		var targetWindow = aWindow || document.commandDispatcher.focusedWindow;
 		if (!targetWindow || Components.lookupMethod(targetWindow, 'top').call(targetWindow) == window)
-			targetWindow = window._content;
+			targetWindow = gBrowser.contentWindow;
 
 		var selection = Components.lookupMethod(targetWindow, 'getSelection').call(targetWindow);
 		if (!selection || !selection.toString()) return nodes;
@@ -1444,53 +1410,34 @@ var ExtCommonUtils = {
 		var node = aNode;
 		while (node)
 		{
-			node = findParentNode(node, aLocalName);
+			node = this.findParentNodeWithLocalName(node, aLocalName);
 			if (!node || node.getAttribute(aAttr)) break;
 			node = node.parentNode;
 		}
 		return (node && node.getAttribute(aAttr)) ? node : null ;
 	},
+	findParentNodeWithLocalName : function(aNode, aLocalName)
+	{
+		var name = String(aLocalName).toLowerCase();
+		var node = aNode;
+		while (node &&
+			String(Components.lookupMethod(node, 'localName').call(node)).toLowerCase() != name)
+			node = Components.lookupMethod(node, 'parentNode').call(node);
+
+		return node;
+	},
  
 	// |bvAbvj[̃Zp[^̕\ 
-	// ʏ́ASẴZp[^̕\IɕύXBtruȅꍇÅ֐Ƀ|bvAbvnꂽiKŕ\ĂZp[^݂̂𐧌䂷B
-	showHideMenuSeparators : function(aPopup, aShouldNotChange)
+	showHideMenuSeparators : function(aPopup)
 	{
-		var i;
-
-		// extract items should be shown
-		var items = aPopup.childNodes;
-		var shownItems = [];
-		for (i = 0; i < items.length; i++)
-		{
-			if (!items[i].hidden ||
-				(!aShouldNotChange && items[i].localName == 'menuseparator'))
-				shownItems.push(items[i]);
-
-			items[i].hidden = true;
-		}
-
-		if (!shownItems.length) return;
-
-		// reject items should be hidden
-		while (shownItems[0].localName == 'menuseparator')
-			shownItems.splice(0, 1);
-
-		while (shownItems[shownItems.length-1].localName == 'menuseparator')
-			shownItems.splice(shownItems.length-1, 1);
-
-		i = 0;
-		while (i != shownItems.length-1)
-		{
-			if (shownItems[i].localName == 'menuseparator' &&
-				shownItems[i+1].localName == 'menuseparator')
-				shownItems.splice(i+1, 1);
-			else
-				i++;
-		}
-
-		// show items
-		for (i in shownItems) shownItems[i].hidden = false;
+		var nodes = this.getNodesFromXPath('descendant::xul:menuseparator[@hidden]', aPopup);
+		for (i = 0; i < nodes.snapshotLength; i++)
+			nodes.snapshotItem(i).removeAttribute('hidden');
 
+		// hide needless separators
+		nodes = this.getNodesFromXPath('descendant::xul:menuseparator[not(following-sibling::*[not(local-name() = "menuseparator") and not(@hidden or @collapsed)]) or not(preceding-sibling::*[not(local-name() = "menuseparator") and not(@hidden or @collapsed)]) or local-name(following-sibling::*[not(@hidden or @collapsed)]) = "menuseparator"]', aPopup);
+		for (i = 0; i < nodes.snapshotLength; i++)
+			nodes.snapshotItem(i).setAttribute('hidden', true);
 	},
  
 	// R}h̎s 
@@ -1584,6 +1531,98 @@ var ExtCommonUtils = {
 		}
 //dump(aContainer.getAttribute('ext-datasource')+' / '+obj.length+'('+aContainer.childNodes.length+')\n');
 	},
+ 
+	getNodesFromXPath : function(aXPath, aContextNode, aType) 
+	{
+		// http://www.hawk.34sp.com/stdpls/xml/
+		// http://www.hawk.34sp.com/stdpls/xml/dom_xpath.html
+		// http://www.homoon.jp/users/www/doc/CR-css3-selectors-20011113.shtml
+		const xmlDoc  = aContextNode ? aContextNode.ownerDocument : document ;
+		const context = aContextNode || xmlDoc.documentElement;
+		const type    = aType || XPathResult.ORDERED_NODE_SNAPSHOT_TYPE;
+		const resolver = {
+			lookupNamespaceURI : function(aPrefix)
+			{
+				switch (aPrefix)
+				{
+					case 'xul':
+					default:
+						return XULNS;
+	//					return '';
+				}
+			}
+		};
+
+
+		var resultObj = (aType == XPathResult.FIRST_ORDERED_NODE_TYPE) ? null :
+				(type == XPathResult.ORDERED_NODE_ITERATOR_TYPE ||
+					type == XPathResult.UNORDERED_NODE_ITERATOR_TYPE) ?
+				{
+					count       : 0,
+					iterateNext : function()
+					{
+						try {
+							return this.XPathResult.iterateNext();
+						}
+						catch(e) {
+							return null;
+						}
+					}
+				} :
+				{
+					get length() {
+						return this.snapshotLength;
+					},
+					get snapshotLength() {
+						return this.XPathResult.snapshotLength;
+					},
+
+					item : function(aIndex)
+					{
+						return this.snapshotItem(aIndex);
+					},
+					snapshotItem : function(aIndex)
+					{
+						return this.XPathResult.snapshotItem(aIndex);
+					}
+				};
+
+		try {
+			var expression = xmlDoc.createExpression(aXPath, resolver);
+			var result     = expression.evaluate(context, type, null);
+
+			if (aType == XPathResult.FIRST_ORDERED_NODE_TYPE)
+				return result.singleNodeValue;
+		}
+		catch(e) {
+			dump('=============getNodesFromXPath===========\n');
+			dump('============____ERROR____============\n');
+			dump('XPath   : '+aXPath+'\n');
+			if (aContextNode)
+				dump('Context : '+aContextNode+'('+aContextNode.localName+')\n');
+			dump(e+'\n');
+			dump('============~~~~ERROR~~~~============\n');
+
+			if (aType == XPathResult.FIRST_ORDERED_NODE_TYPE)
+				return null;
+
+			resultObj.XPathResult = {
+				snapshotLength : 0,
+				snapshotItem : function()
+				{
+					return null;
+				},
+				iterateNext : function()
+				{
+					return null;
+				}
+			};
+			return resultObj;
+		}
+
+		resultObj.XPathResult = result;
+		return resultObj;
+	},
   
 	readCSSFor : function(aTextboxOrID) 
 	{
@@ -1826,7 +1865,7 @@ var ExtCommonUtils = {
 	}
  
 }; 
-  
+ 
 //  
 // initialize
 window.addEventListener('load', function()
