@@ -1,6 +1,4 @@
-// Mozillão[WƂ̈Ⴂɂ鏈́A 
-// [[interchangeability for NS6]] Ȃǂ̃xŎĂB
-
+// 
 var extCustomScripts = [];
 var extCustomScriptsTemp;
 var gExtContextWindow = null;
@@ -44,7 +42,7 @@ var ExtFunc = {
 
 			uri = this.utils.makeURIComplete(uri, this.service.currentURI());
 
-			this.service.loadURI(uri, null, this.utils.getPref('ctxextensions.new_window.openSelectionAsURI'));
+			this.service.loadURI(uri, null, this.utils.getPref('ctxextensions.showResultIn.openSelectionAsURI'));
 			break;
 
 
@@ -71,45 +69,31 @@ var ExtFunc = {
 			uri = w.location.href;
 			uri = uri.split('#')[0];
 			uri = (ExtService.canUp && uri.match(/\/(index[^\/]*)?$/i)) ? ExtService.getParentDir(uri) : ExtService.getCurrentDir(uri) ;
-			this.service.loadURI(uri/*, this.utils.makeURIFromSpec(w.location.href)*/); // HTTP_REFERER must not be sent when the URI doesn't exist in the original document (RFC2616 14.36)
+			this.service.loadURI(uri/*, this.utils.makeURIFromSpec(w.location.href)*/, null, this.utils.getPref('ctxextensions.showResultIn.up')); // HTTP_REFERER must not be sent when the URI doesn't exist in the original document (RFC2616 14.36)
 			break;
 
 		case 'openciteforquote':
 			uri = this.service.getCiteForQuote();
 			if (!uri) return;
-			this.service.loadURI(uri, this.utils.makeURIFromSpec(this.service.currentURI()), this.utils.getPref('ctxextensions.new_window.openCiteForQuote'));
+			this.service.loadURI(uri, this.utils.makeURIFromSpec(this.service.currentURI()), this.utils.getPref('ctxextensions.showResultIn.openCiteForQuote'));
 			break;
 		case 'openciteforedit':
 			uri = this.service.getCiteForEdit();
 			if (!uri) return;
-			this.service.loadURI(uri, this.utils.makeURIFromSpec(this.service.currentURI()), this.utils.getPref('ctxextensions.new_window.openCiteForEdit'));
+			this.service.loadURI(uri, this.utils.makeURIFromSpec(this.service.currentURI()), this.utils.getPref('ctxextensions.showResultIn.openCiteForEdit'));
 			break;
 		case 'openlongdesc':
 			uri = this.service.getLongdesc();
 			if (!uri) return;
-			this.service.loadURI(uri, this.utils.makeURIFromSpec(this.service.currentURI()), this.utils.getPref('ctxextensions.new_window.openLongdesc'));
+			this.service.loadURI(uri, this.utils.makeURIFromSpec(this.service.currentURI()), this.utils.getPref('ctxextensions.showResultIn.openLongdesc'));
 			break;
 
 
 		case 'pref':
-			if ('goPreference' in window)
-				window.goPreferences(
-					'ctxextensions-root',
-					'chrome://ctxextensions/content/pref/pref-about.xul',
-					'ctxextensions-root');
-			else // new Firefox
-				window.openDialog(
-					'chrome://ctxextensions/content/pref/prefDialog.xul',
-					'ExtPrefWindow',
-					'chrome,all,dependent');
-			break;
-
-		case 'help':
-			this.service.loadURI(
-				'chrome://ctxextensions/locale/help.xml',
-				null,
-				this.utils.getPref('ctxextensions.new_window.help'),
-				true);
+			window.openDialog(
+				'chrome://ctxextensions/content/pref/prefDialog.xul',
+				'ExtPrefWindow',
+				'chrome,all,dependent');
 			break;
 
 
@@ -133,94 +117,37 @@ var ExtFunc = {
 	Navigations : function(aEvent)
 	{
 		var uri = aEvent.target.value;
-		this.service.loadURI(uri, this.utils.makeURIFromSpec(this.service.currentURI()), this.utils.getPref('ctxextensions.new_window.navigations'));
+		this.service.loadURI(uri, this.utils.makeURIFromSpec(this.service.currentURI()), this.utils.getPref('ctxextensions.showResultIn.navigations'));
 		aEvent.preventBubble();
-		return;
 	},
  
 	// s̕\ 
 	
-	showInvisibleInfo : function(aType, aFilterFlags, aFilter, aCallBackFunc, aDefaultStatus, aWindow) 
+	showInvisibleInfo : function(aXPath, aCallBackFunc, aWindow) 
 	{
-		var d    = (aWindow ? aWindow.document : this.service.contentDocument()),
-			info = this.service.contentInfo(false, d.defaultView);
-
-		var runningFlag = 'runningShowWalkerFor'+aType;
-		var manager     = 'showInvisibleInfoFor'+aType;
-		var lastNode    = 'showWalkerLastNodeFor'+aType;
-		var lastIndex   = 'showWalkerLastIndextFor'+aType;
-
-		if (runningFlag in info && info[runningFlag]) return;
-		info[runningFlag] = true;
-
-		var b = this.service.getBrowserForDocument(d);
-		if (manager in b && b[manager]) {
-			b[manager].stop();
-			b[manager] = null;
-		}
-
-		b[manager] = new pProgressTreeWalker();
-		b[manager].initWithTreeWalker(
-			d, aFilterFlags, aFilter, false,
-			this.showInvisibleInfoObserver, 1, /*b, */'progress', aDefaultStatus.replace(/%host%/g, this.utils.makeURIFromSpec(document.location.href).host || this.service.message.unknown_host)
-		);
-		b[manager].appendItem(info, aType, aCallBackFunc);
-		b[manager].max = d.getElementsByTagName('*').length;
-
-		if (lastNode in info && info[lastNode]) {
-			b[manager].walker.currentNode = info[lastNode];
-			b[manager].count = info[lastIndex];
-		}
-
-		b[manager].start();
+		var d = (aWindow ? aWindow.document : this.service.contentDocument());
 
 		this.applyStyleForShowItems(aWindow);
 
-		return;
-	},
-	showInvisibleInfoObserver :
-	{
-		onProgress : function(aManager, aNode, aInfo, aType, aCallBackFunc)
-		{
-			if (!aInfo || !aNode || !aNode.ownerDocument) return; // failsafe
-
-			var callBackFunc = aCallBackFunc;
-			callBackFunc(aNode);
-		},
-		onProgressEnd : function(aManager, aInfo, aType)
-		{
-			if (!aInfo) return; // failsafe
-
-			aInfo['runningShowWalkerFor'+aType] = false;
-			if ('showWalkerLastNodeFor'+aType in aInfo &&
-				aInfo['showWalkerLastNodeFor'+aType] == aManager.lastNode)
-				return;
-			aInfo['showWalkerLastNodeFor'+aType] = aManager.lastNode;
-			aInfo['showWalkerLastIndextFor'+aType] = aManager.count;
-		}
+		var nodes = this.utils.getNodesFromXPath(aXPath, d.documentElement);
+		var max = nodes.snapshotLength;
+		for (var i = 0; i < max; i++)
+			aCallBackFunc(nodes.snapshotItem(i));
 	},
  
 	// Rg̉ 
 	showComment : function(aWindow)
 	{
 		this.showInvisibleInfo(
-			'Comments',
-			NodeFilter.SHOW_COMMENT,
-			this.getCommentFilter,
+			'/descendant::comment()',
 			this.makeCommentStrings,
-			this.service.message.status_comment,
 			aWindow
 		);
 	},
-	getCommentFilter :
-	{
-		acceptNode : function(aNode)
-		{
-			return ('ex_comment_visible' in aNode) ? NodeFilter.FILTER_SKIP : NodeFilter.FILTER_ACCEPT ;
-		}
-	},
 	makeCommentStrings : function(aNode)
 	{
+		if (aNode.ex_comment_visible) return;
+
 		aNode.ex_comment_visible = true;
 
 		var output = document.createElementNS(ExtService.EXNS, 'comment');
@@ -234,32 +161,14 @@ var ExtFunc = {
 	showLink : function(aWindow)
 	{
 		this.showInvisibleInfo(
-			'Links',
-			NodeFilter.SHOW_ELEMENT,
-			this.getLinkFilter,
+			'/descendant::*[(@href or @longdesc) and not(@ex_link_visible)]',
 			this.makeLinkStrings,
-			this.service.message.status_link,
 			aWindow
 		);
 	},
-	getLinkFilter :
-	{
-		acceptNode : function(aNode)
-		{
-			var href = ('href' in aNode && aNode.href) ? aNode.href :
-					('longdesc' in aNode && aNode.longdesc) ? aNode.longdesc :
-					aNode.getAttributeNS(ExtService.XHTMLNS, 'href') ||
-					aNode.getAttributeNS(ExtService.XLinkNS, 'href') ||
-					aNode.getAttributeNS(ExtService.XHTMLNS, 'longdesc') ;
-			return (!href ||
-					('ext_generated' in aNode) ||
-					('ex_link_visible' in aNode) ||
-					aNode.namespaceURI == ExtService.EXNS) ? NodeFilter.FILTER_SKIP : NodeFilter.FILTER_ACCEPT ;
-		}
-	},
 	makeLinkStrings : function(aNode)
 	{
-		aNode.ex_link_visible = true;
+		aNode.setAttribute('ex_link_visible', true);
 
 		var href = ('href' in aNode && aNode.href) ? aNode.href :
 				aNode.getAttributeNS(ExtService.XHTMLNS, 'href') ||
@@ -304,25 +213,15 @@ var ExtFunc = {
 	showID : function(aWindow)
 	{
 		this.showInvisibleInfo(
-			'IDs',
-			NodeFilter.SHOW_ELEMENT,
-			this.getIdFilter,
+			'/descendant::*[(@id or @name) and not(@ex_id_visible)]',
 			this.makeIdStrings,
-			this.service.message.status_id,
 			aWindow
 		);
 	},
-	getIdFilter :
-	{
-		acceptNode : function(aNode)
-		{
-			return ((!aNode.id && (!('name' in aNode) || !aNode.name)) ||
-					('ex_id_visible' in aNode)) ? NodeFilter.FILTER_SKIP : NodeFilter.FILTER_ACCEPT ;
-		}
-	},
 	makeIdStrings : function(aNode)
 	{
-		aNode.ex_id_visible = true;
+		aNode.setAttribute('ex_id_visible', true);
+		if (!aNode.id && !aNode.name) return;
 
 		var label_inner = aNode.id || aNode.name ;
 		var label = ExtService.message.id.replace(/%s/i, aNode.id || aNode.name) ;
@@ -342,26 +241,15 @@ var ExtFunc = {
 	showCite : function(aWindow)
 	{
 		this.showInvisibleInfo(
-			'Cites',
-			NodeFilter.SHOW_ELEMENT,
-			this.getCiteFilter,
+			'/descendant::*[(@cite or @longdesc) and not(@ex_cite_visible)]',
 			this.makeCiteStrings,
-			this.service.message.status_cite,
 			aWindow
 		);
 	},
-	getCiteFilter :
-	{
-		acceptNode : function(aNode)
-		{
-			var cite = ('cite' in aNode && aNode.cite) ? aNode.cite :
-						aNode.getAttributeNS(ExtService.XHTMLNS, 'longdesc') ;
-			return (!cite || 'ex_cite_visible' in aNode) ? NodeFilter.FILTER_SKIP : NodeFilter.FILTER_ACCEPT ;
-		}
-	},
 	makeCiteStrings : function(aNode)
 	{
-		aNode.ex_cite_visible = true;
+		aNode.setAttribute('ex_cite_visible', true);
+		if (!aNode.cite && !aNode.getAttributeNS(ExtService.XHTMLNS, 'longdesc')) return;
 
 		var cite = ('cite' in aNode && aNode.cite) ? aNode.cite :
 					aNode.getAttributeNS(ExtService.XHTMLNS, 'longdesc') ;
@@ -382,34 +270,15 @@ var ExtFunc = {
 	showTitle : function(aWindow)
 	{
 		this.showInvisibleInfo(
-			'Titles',
-			NodeFilter.SHOW_ELEMENT,
-			this.getTitleFilter,
+			'/descendant::*[(@title or @summary or @alt) and not(@ex_title_visible)]',
 			this.makeTitleStrings,
-			this.service.message.status_title,
 			aWindow
 		);
 	},
-	getTitleFilter :
-	{
-		acceptNode : function(aNode)
-		{
-			var desc = ('title' in aNode && aNode.title) ? aNode.title :
-					('summary' in aNode && aNode.summary) ? aNode.summary :
-					('alt' in aNode && aNode.alt) ? aNode.alt :
-					aNode.getAttributeNS(ExtService.XHTMLNS, 'title') ||
-					aNode.getAttributeNS(ExtService.XLinkNS, 'title') ||
-					aNode.getAttributeNS(ExtService.XHTMLNS, 'summary') ||
-					aNode.getAttributeNS(ExtService.XHTMLNS, 'alt') ;
-			return (!desc ||
-					'ext_generated' in aNode ||
-					'ex_title_visible' in aNode ||
-					aNode.namespaceURI == ExtService.EXNS) ? NodeFilter.FILTER_SKIP : NodeFilter.FILTER_ACCEPT ;
-		}
-	},
 	makeTitleStrings : function(aNode)
 	{
-		aNode.ex_title_visible = true;
+		aNode.setAttribute('ex_title_visible', true);
+		if (!aNode.title && !aNode.alt && !aNode.getAttributeNS(ExtService.XHTMLNS, 'longdesc')) return;
 
 		var title = ('title' in aNode && aNode.title) ? aNode.title :
 				aNode.getAttributeNS(ExtService.XHTMLNS, 'title') ||
@@ -440,32 +309,14 @@ var ExtFunc = {
 	showEventHandler : function(aWindow)
 	{
 		this.showInvisibleInfo(
-			'Events',
-			NodeFilter.SHOW_ELEMENT,
-			this.getEventFilter,
+			'/descendant::*[not(@ex_event_visible)][attribute::*[starts-with(local-name(), "ON") or starts-with(local-name(), "on")]]',
 			this.makeEventStrings,
-			this.service.message.status_event,
 			aWindow
 		);
 	},
-	getEventFilter :
-	{
-		acceptNode : function(aNode)
-		{
-			var attr = aNode.attributes;
-			if (!attr || !attr.length || 'ex_event_visible' in aNode)
-				return NodeFilter.FILTER_SKIP;
-
-			for (var i = 0; i < attr.length; i++)
-				if (attr[i].name.toLowerCase().substring(0, 2) == 'on')
-					return NodeFilter.FILTER_ACCEPT;
-
-			return NodeFilter.FILTER_SKIP;
-		}
-	},
 	makeEventStrings : function(aNode)
 	{
-		aNode.ex_event_visible = true;
+		aNode.setAttribute('ex_event_visible', true);
 
 		var attr = aNode.attributes;
 		var output = document.createElementNS(ExtService.EXNS, 'event');
@@ -545,12 +396,15 @@ var ExtFunc = {
 				this.service.setStyleTo(value, w.top, true);
 		}
 		else {
+			var idAttrString = escape(id).replace(/%/g, '-');
 			// check selected status
-			var checked = (this.utils.STYLESHEETS.getData(id, 'Selected') == 'true');
+			var checked = gBrowser.selectedTab.hasAttribute('ctxextensions-optionalstylesheet-'+idAttrString) ?
+				(gBrowser.selectedTab.getAttribute('ctxextensions-optionalstylesheet-'+idAttrString) == 'true') :
+				(this.utils.STYLESHEETS.getData(id, 'Selected') == 'true');
 
 			// Ԃۑ
 			if (aShouldSave)
-				this.utils.STYLESHEETS.setData(id, 'Selected', (!checked ? 'true' : 'false' ));
+				gBrowser.selectedTab.setAttribute('ctxextensions-optionalstylesheet-'+idAttrString, !checked ? 'true' : 'false' );
 
 			// for preset items
 			if (typeof aEventOrID != 'string') {
@@ -600,23 +454,34 @@ var ExtFunc = {
  
 	toggleOptionalStyleRules : function(aID, aRules, aWindow, aForcedSetOrUnset) 
 	{
-		var d    = (aWindow ? aWindow.document : this.service.contentDocument() );
-		var info = this.service.contentInfo(false, d.defaultView);
-		var id   = 'UserdefinedStyleSheet:'+aID+':'+d.location.href;
+		var d    = (aWindow ? aWindow.document : this.service.contentDocument() ),
+			w    = (aWindow ? aWindow : gBrowser.contentWindow ),
+			info = this.service.contentInfo(false, w);
+		var id   = 'UserdefinedStyleSheet:'+aID+':'+d.URL;
 
 		if (!('sheet' in info)) info.sheet = [];
 
+
 		// if the flag to force to set/unset style is different from current stored status of data, save new status
-		if (aForcedSetOrUnset !== void(0) &&
-			(this.utils.STYLESHEETS.getData(aID, 'Selected') == 'true') != aForcedSetOrUnset)
-			this.utils.STYLESHEETS.setData(aID, 'Selected', aForcedSetOrUnset ? 'true' : 'false' );
+
+		// check selected status
+		var idAttrString = escape(aID).replace(/%/g, '-');
+		var checked = gBrowser.selectedTab.hasAttribute('ctxextensions-optionalstylesheet-'+idAttrString) ?
+			(gBrowser.selectedTab.getAttribute('ctxextensions-optionalstylesheet-'+idAttrString) == 'true') :
+			(this.utils.STYLESHEETS.getData(aID, 'Selected') == 'true');
+
+		if (aForcedSetOrUnset !== void(0) && checked != aForcedSetOrUnset) {
+			gBrowser.selectedTab.setAttribute('ctxextensions-optionalstylesheet-'+idAttrString, aForcedSetOrUnset ? 'true' : 'false' );
+			checked = aForcedSetOrUnset;
+		}
+
 
 		if (this.utils.STYLESHEETS.getData(aID, 'Cancel') == 'true')
 			this.cancelStyles();
 
 		if ((aForcedSetOrUnset === void(0) || !aForcedSetOrUnset) &&
 			id in info.sheet && info.sheet[id]) {
-			info.sheet[id].disabled = !(this.utils.STYLESHEETS.getData(aID, 'Selected') == 'true');
+			info.sheet[id].disabled = !checked;
 		}
 		else { // append stylesheet
 			if (id in info.sheet && info.sheet[id]) return;
@@ -637,7 +502,7 @@ var ExtFunc = {
 				rules = '';
 			}
 
-			this.service.appendStyleSheet(id, path, d.defaultView, rules);
+			this.service.appendStyleSheet(id, path, w, rules);
 		}
 	},
  
@@ -667,7 +532,7 @@ var ExtFunc = {
 					(!aEventOrID && !sheets[i].title)) {
 					embedded.push(false);
 					value.push(sheets[i].href);
-					if (value[i] == d.location.href) {
+					if (value[i] == d.URL) {
 						embedded[embedded.length-1] = true;
 						value[value.length-1] = sheets[i].ownerNode.firstChild.nodeValue;
 					}
@@ -677,7 +542,6 @@ var ExtFunc = {
 		if (!value) return;
 
 
-		var newWin = this.utils.getPref('ctxextensions.new_window.styleSheets');
 		var ref = this.utils.makeURIFromSpec(aWindow ? aWindow.location.href : this.service.currentURI() );
 
 		for (i in value)
@@ -692,12 +556,27 @@ var ExtFunc = {
 				);
 			}
 			else {
-				if (newWin)
-					this.service.loadURI(value[i], ref, newWin);
-				else if (i == 0)
-					this.service.loadURI(value[i], ref);
-				else
-					this.service.openNewTab(value[i], ref, newWin);
+				switch (this.utils.getPref('ctxextensions.showResultIn.styleSheets'))
+				{
+					default:
+					case 0:
+						if (i == 0) {
+							this.service.openNewTab(value[i], ref);
+							break;
+						}
+
+					case 10:
+						this.service.loadURI(value[i], ref, this.service.NEW_TAB);
+						break;
+
+					case 11:
+						this.service.loadURI(value[i], ref, this.service.NEW_BG_TAB);
+						break;
+
+					case 20:
+						this.service.loadURI(value[i], ref, this.service.NEW_WINDOW);
+						break;
+				}
 			}
 		}
 	},
@@ -755,10 +634,13 @@ var ExtFunc = {
 		switch(openIn)
 		{
 			case 'NewWindow':
-				this.service.loadURI(uri, null, true);
+				this.service.loadURI(uri, null, this.service.NEW_WINDOW);
 				break;
 			case 'NewTab':
-				this.service.openNewTab(uri);
+				this.service.openNewTab(uri, null, this.service.NEW_TAB);
+				break;
+			case 'NewBackgroundTab':
+				this.service.openNewTab(uri, null, this.service.NEW_BG_TAB);
 				break;
 			default:
 				this.service.loadURI(uri);
@@ -793,13 +675,19 @@ var ExtFunc = {
 		switch(openIn)
 		{
 			case 'NewWindow':
-				this.service.loadURI(uri, null, true);
+				this.service.loadURI(uri, null, this.service.NEW_WINDOW);
 				break;
 			case 'NewTab':
 				if (this.utils.browserWindow.ExtService.currentURI(true) != 'about:blank') {
-					this.service.openNewTab(uri);
+					this.service.openNewTab(uri, null, this.service.NEW_TAB);
 					break;
 				}
+			case 'NewBackgroundTab':
+				if (this.utils.browserWindow.ExtService.currentURI(true) != 'about:blank') {
+					this.service.openNewTab(uri, null, this.service.NEW_BG_TAB);
+					break;
+				}
+				break;
 			default:
 				this.service.loadURI(uri);
 				break;
@@ -828,19 +716,21 @@ var ExtFunc = {
 
 		if (arg.match(/%c/i)) {
 			var str = aString || this.service.getSelection() || '' ;
+			arg = arg.replace(/%c/ig, str);
 
 			// Unicode w肳ꂽR[h֕ϊ
 			var charset = this.utils.EXECAPPS.getData(id, 'Charset') || this.utils.getPref('ctxextensions.sendStrCharset');
 			if (charset != 'UTF-8') {
 				this.utils.UCONV.charset = charset;
-				str = this.utils.UCONV.ConvertFromUnicode(str);
+//				str = this.utils.UCONV.ConvertFromUnicode(str);
+				arg = this.utils.UCONV.ConvertFromUnicode(arg);
 			}
-			arg = arg.replace(/%c/ig, str);
+//			arg = arg.replace(/%c/ig, str);
 		}
 
 		var d = this.service.contentDocument(aShouldOpenTopFrame);
-		if (down || d.location.href.match(/^(chrome|resource|data):/)) {
-			if (!d.location || d.location.href != uri) d = null;
+		if (down || d.URL.match(/^(chrome|resource|data):/)) {
+			if (!d.location || d.URL != uri) d = null;
 			this.service.downloadAndOpenWithApp('EXECAPP:'+path, path, arg, uri, d);
 		}
 		else
@@ -895,7 +785,7 @@ var ExtFunc = {
 
 		try {
 			// windowIuWFNg̃\bhɂ
-			eval(['window.extCustomScripts[id] = function() {', script, '}'].join('\n\r'));
+			eval(['window.extCustomScripts[id] = function() { with(window) {', script, '} }'].join('\n\r'));
 			return window.extCustomScripts[id]();
 //			delete window.extCustomScripts[id];
 //			return ret;
@@ -930,12 +820,13 @@ var ExtFunc = {
 
 		this.service.updateHeadings(aWindow);
 
-		var d = (aWindow ? aWindow.document : this.service.contentDocument() );
-		var info = this.service.contentInfo(false, d.defaultView);
+		var d    = (aWindow ? aWindow.document : this.service.contentDocument()),
+			w    = (aWindow ? aWindow : gBrowser.contentWindow ),
+			info = this.service.contentInfo(false, w);
 		if (!info.headings || !info.headings.length) return;
 
 		// AJ[猻݂̌o擾B擾łȂ΁A̒lB
-		var uri     = d.location.href.split('#');
+		var uri     = d.URL.split('#');
 		var current =
 			(uri[1] &&
 			info.headingsIndex &&
@@ -1045,7 +936,11 @@ var ExtFunc = {
 			{
 				// N^CvNȏ゠ꍇA|bvAbvőI
 
-				while (popup.childNodes.length) popup.removeChild(popup.lastChild);
+				var range = document.createRange();
+				range.selectNodeContents(popup);
+				range.deleteContents();
+				range.detach();
+
 				for (i = 0; i < nodes.length; i++)
 				{
 					menuitem = document.createElement('menuitem');
@@ -1171,7 +1066,8 @@ var ExtFunc = {
 		var d = (aWindow ? aWindow.document : this.service.contentDocument());
 		if (!d) return; // failsafe
 
-		var info = this.service.contentInfo(false, d.defaultView);
+		var w    = (aWindow ? aWindow : gBrowser.contentWindow ),
+			info = this.service.contentInfo(false, w);
 		if ('showAutoFinished' in info) return;
 
 		var prefs = {
@@ -1198,7 +1094,8 @@ var ExtFunc = {
 		var d = (aWindow ? aWindow.document : this.service.contentDocument());
 		if (!d) return; // failsafe
 
-		var info = this.service.contentInfo(false, d.defaultView);
+		var w    = (aWindow ? aWindow : gBrowser.contentWindow ),
+			info = this.service.contentInfo(false, w);
 		if ('execautoFinished' in info ||
 			!this.utils.getPref('ctxextensions.autoexec.customScripts')) return;
 
@@ -1209,7 +1106,7 @@ var ExtFunc = {
 		{
 			item = CSObj.item(i);
 			if (CSObj.getData(item, 'Automatically') == 'true')
-				ret = this.CustomScripts(CSObj.getData(item, 'Name'), null, d.defaultView);
+				ret = this.CustomScripts(CSObj.getData(item, 'Name'), null, w);
 		}
 
 		info.execautoFinished = true;
@@ -1223,13 +1120,15 @@ var ExtFunc = {
 	AddOptionalStyleSheets : function(aWindow)
 	{
 		var d    = (aWindow ? aWindow.document : this.service.contentDocument()),
-			info = this.service.contentInfo(false, d.defaultView);
+			w    = (aWindow ? aWindow : gBrowser.contentWindow ),
+			info = this.service.contentInfo(false, w);
 
 		if ('addOptionalStyleSheetsDone' in info) return;
 
 		var SSObj = this.utils.STYLESHEETS,
 			item,
-			name;
+			name,
+			idAttrString;
 
 		for (var i = 0; i < SSObj.length; i++)
 		{
@@ -1237,8 +1136,12 @@ var ExtFunc = {
 			if (!item) continue;
 
 			name = SSObj.getID(item);
-			if (SSObj.getData(item, 'Selected') == 'true')
-				this.toggleOptionalStyleRules(name, null, d.defaultView, true);
+			idAttrString = escape(name).replace(/%/g, '-');
+
+			if (gBrowser.selectedTab.hasAttribute('ctxextensions-optionalstylesheet-'+idAttrString) ?
+				(gBrowser.selectedTab.getAttribute('ctxextensions-optionalstylesheet-'+idAttrString) == 'true') :
+				(SSObj.getData(item, 'Selected') == 'true'))
+				this.toggleOptionalStyleRules(name, null, w, true);
 		}
 
 		info.addOptionalStyleSheetsDone = true;
@@ -1250,11 +1153,12 @@ var ExtFunc = {
 	RestoreSelectedStyle : function(aWindow, aRequest)
 	{
 		var d    = (aWindow ? aWindow.document : this.service.contentDocument()),
-			info = this.service.contentInfo(false, d.defaultView);
+			w    = (aWindow ? aWindow : gBrowser.contentWindow ),
+			info = this.service.contentInfo(false, w);
 
 		if ('restoreStyleDone' in info) return;
 
-		var path = this.utils.getCurrentDir(d.location.href);
+		var path = this.utils.getCurrentDir(d.URL);
 		var style = this.utils.SELECTEDSTYLES.getDataFromPath(path, 'SelectedStyle') || '' ;
 		var id = this.utils.SELECTEDSTYLES.getDataFromPath(path, 'SelectedStyleID');
 
@@ -1281,7 +1185,7 @@ var ExtFunc = {
 			// ۑĂ閼ÕX^CȂꍇAȂ
 //			var hasSavedStyle = this.service.hasStyle(d, style);
 //			if (hasSavedStyle)
-				this.service.selectStyleSheet(d.location.href, style, d.defaultView);
+				this.service.selectStyleSheet(d.URL, style, w);
 		}
 
 		info.restoreStyleDone = true;
@@ -1314,7 +1218,8 @@ var ExtFunc = {
 	applyStyleForShowItems : function(aWindow) 
 	{
 		var d    = (aWindow ? aWindow.document : this.service.contentDocument()),
-			info = this.service.contentInfo(false, d.defaultView);
+			w    = (aWindow ? aWindow : gBrowser.contentWindow ),
+			info = this.service.contentInfo(false, w);
 
 		if ('showStyleRuleDone' in info) return;
 
@@ -1326,7 +1231,7 @@ var ExtFunc = {
 					'eventlabel  {\n'+this.utils.getPref('ctxextensions.style.showEvents.label', true)+'\n}\n'+
 					'eventvalue  {\n'+this.utils.getPref('ctxextensions.style.showEvents.value', true)+'\n}\n';
 
-		this.service.appendStyleSheet('ShowItems:'+d.location.href, this.service.content+'res/_EXNS.css?ShowItems', d.defaultView, rules);
+		this.service.appendStyleSheet('ShowItems:'+d.URL, this.service.content+'res/_EXNS.css?ShowItems', w, rules);
 		info.showStyleRuleDone = true;
 		return;
 	},
