@@ -40,12 +40,10 @@ var PrefUtils = {
 	init : function() 
 	{
 		this.initMacLabels();
-		this.initDisabledItems();
 		this.initElementIDs();
 		this.initExpert();
 		this.initSamples();
 		this.initOperatorsForListItem();
-		this.insertHelpButton();
 
 		window.parent.initPanel(location.href);
 
@@ -67,27 +65,6 @@ var PrefUtils = {
 		}
 	},
  
-	initDisabledItems : function() 
-	{
-		var rev   = this.utils.mozRevision;
-		var prefs = {
-				'accessibility.typeaheadfind'                : (rev < 1.2),
-				'accessibility.typeaheadfind.linksonly'      : (rev < 1.2),
-				'accessibility.typeaheadfind.startlinksonly' : (rev < 1.2),
-				'accessibility.typeaheadfind.timeout'        : (rev < 1.2)
-			};
-
-		for (var i in prefs)
-		{
-			elem = document.getElementsByAttribute('prefstring', i);
-			if (elem.length && prefs[i]) {
-				elem[0].setAttribute('checked',  false);
-				elem[0].setAttribute('disabled', true);
-				elem[0].removeAttribute('prefstring');
-			}
-		}
-	},
- 
 	initElementIDs : function() 
 	{
 		if (!('_elementIDs' in window))
@@ -151,33 +128,6 @@ var PrefUtils = {
 		for (i = 0; i < nodes.length; i++)
 			nodes[i].setAttribute('disabled', true);
 	},
- 
-	// wvJ{^ǉ 
-	insertHelpButton : function()
-	{
-		var helpid = document.documentElement.getAttribute('helpid');
-		if (helpid) helpid = '#'+helpid;
-
-		var helpButton = document.createElement('button');
-		helpButton.setAttribute('label', this.utils.getMsg('pref_help_label'));
-		helpButton.setAttribute('oncommand', 'var uri = "chrome://ctxextensions/locale/help-prefs.xml'+helpid+'"; var w = ExtCommonUtils.browserWindow; if (w) { w.ExtCommonUtils.browser.loadURI(uri); w.ExtCommonUtils.browser.loadURI(uri); w.focus(); } else { window.open(uri); }');
-
-		var spacer = document.createElement('spacer');
-		spacer.setAttribute('flex', '1');
-
-		var box = document.createElement('box');
-		box.setAttribute('orient', 'horizontal');
-		box.setAttribute('id', 'button-help');
-		box.appendChild(spacer.cloneNode(true));
-		box.appendChild(helpButton);
-
-		var container = document.createElement('box');
-		container.setAttribute('orient', 'vertical');
-		container.appendChild(spacer);
-		container.appendChild(box);
-
-		document.documentElement.appendChild(container);
-	},
   
 	// t@CI_CAO 
 	getFilePathFor : function(aTextboxId, aTitle, aSaveMode)
@@ -355,7 +305,8 @@ var PrefUtils = {
 				return;
 			}
 
-		window.openDialog('chrome://ctxextensions/content/pref/prefProperty.xul', '_blank', 'chrome,all,dialog=no,centerscreen', data);
+		var dialog = window.openDialog('chrome://ctxextensions/content/pref/prefProperty.xul', '_blank', 'chrome,all,dialog=no,centerscreen', data);
+		dialog.setTimeout('window.focus()', 500);
 	},
  
 	renameListItem : function(aNode, aRDFData) 
