@@ -122,12 +122,14 @@ var PrefPropService = {
   
 	init : function() 
 	{
+dump('0\n');
 		var i;
 
 		if ('name' in this.data && this.data.name)
 			document.documentElement.setAttribute('title', document.documentElement.getAttribute('title-for').replace(/%s/gi, this.data.name));
 
 
+dump('1\n');
 		if (this.isSample) {
 			document.documentElement.getButton('accept').hidden = true;
 		}
@@ -139,6 +141,8 @@ var PrefPropService = {
 			}
 		}
 
+dump('2\n');
+try{
 		this.initEditor();
 		this.initApplication();
 		this.initWebService();
@@ -146,8 +150,9 @@ var PrefPropService = {
 		this.initCharset();
 		this.initOpenIn();
 		this.initKeyboardShortcut();
+}catch(e){alert(e);}
 
-
+dump('3\n');
 		// hide options tab
 		var panel = document.getElementById('tabpanel-options');
 		var count = 0;
@@ -157,10 +162,12 @@ var PrefPropService = {
 			document.getElementById('tab-options').hidden = true;
 
 
+dump('4\n');
 
 		if (this.isSample) {
 			document.documentElement.getButton('extra1').label = document.getElementById('saveSample-label').getAttribute('label');
 		}
+dump('5\n');
 
 //		alert(this.activatedItems.join('\n'));
 	},
@@ -272,7 +279,7 @@ var PrefPropService = {
 
 		if (count < 2) {
 			var container = document.getElementById('contextChecks');
-			document.getElementById('checkboxes').appendChild(container.removeChild(this.contextChecks[0]));
+			document.getElementById('checkboxes').appendChild(this.contextChecks[0].parentNode.removeChild(this.contextChecks[0]));
 			container.hidden = true;
 		}
 	},
